@@ -4,7 +4,7 @@ package WAP::wbxml;
 use strict;
 use warnings;
 
-our $VERSION = '1.13';
+our $VERSION = '1.14';
 
 =head1 NAME
 
@@ -119,7 +119,7 @@ sub compileDatetime {
     my $self = shift;
     my ($content) = @_;
     my $str;
-    if ($content =~ /(\d+)-(\d+)-(\d+)T(\d+)\.(\d+)\.(\d+)Z/) {
+    if ($content =~ /(\d+)-(\d+)-(\d+)T(\d+):(\d+):(\d+)Z/) {
         my $year  = chr (16 * ($1 / 1000) + (($1 / 100) % 10))
                   . chr (16 * (($1 / 10) % 10) + ($1 % 10));
         my $month = chr (16 * ($2 / 10) + ($2 % 10));
@@ -734,7 +734,7 @@ wbxmlc, WAP::SAXDriver::wbxml
 
 =head1 COPYRIGHT
 
-(c) 2001-2011 Francois PERRAD, France.
+(c) 2001-2016 Francois PERRAD, France.
 
 This program (WAP::wbxml.pm and the internal DTD of wbrules.xml) is distributed
 under the terms of the Artistic Licence.
